==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-category-chart-module.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { IgrLineSeriesModule } from './igr-line-series-module';
import { IgrAreaSeriesModule } from './igr-area-series-module';
import { IgrColumnSeriesModule } from './igr-column-series-module';
import { IgrSplineSeriesModule } from './igr-spline-series-module';
import { IgrSplineAreaSeriesModule } from './igr-spline-area-series-module';
import { IgrStepLineSeriesModule } from './igr-step-line-series-module';
import { IgrStepAreaSeriesModule } from './igr-step-area-series-module';
import { IgrPointSeriesModule } from './igr-point-series-module';
import { IgrWaterfallSeriesModule } from './igr-waterfall-series-module';
import { IgrNumberAbbreviatorModule } from './igr-number-abbreviator-module';
import { IgrCrosshairLayerModule } from './igr-crosshair-layer-module';
import { IgrCalloutLayerModule } from './igr-callout-layer-module';
import { IgrItemToolTipLayerModule } from './igr-item-tool-tip-layer-module';
import { IgrCategoryToolTipLayerModule } from './igr-category-tool-tip-layer-module';
import { IgrCategoryHighlightLayerModule } from './igr-category-highlight-layer-module';
import { IgrCategoryItemHighlightLayerModule } from './igr-category-item-highlight-layer-module';
import { IgrFinalValueLayerModule } from './igr-final-value-layer-module';
import { IgrDataChartInteractivityModule } from './igr-data-chart-interactivity-module';
import { IgrDataChartCategoryTrendLineModule } from './igr-data-chart-category-trendline-module';
import { IgrDataChartAnnotationModule } from './igr-data-chart-annotation-module';
var IgrCategoryChartModule = /** @class */ (function () {
    function IgrCategoryChartModule() {
    }
    IgrCategoryChartModule.register = function () {
        IgrLineSeriesModule.register();
        IgrAreaSeriesModule.register();
        IgrColumnSeriesModule.register();
        IgrSplineSeriesModule.register();
        IgrSplineAreaSeriesModule.register();
        IgrStepLineSeriesModule.register();
        IgrStepAreaSeriesModule.register();
        IgrPointSeriesModule.register();
        IgrWaterfallSeriesModule.register();
        IgrNumberAbbreviatorModule.register();
        IgrDataChartInteractivityModule.register();
        IgrCrosshairLayerModule.register();
        IgrCalloutLayerModule.register();
        IgrItemToolTipLayerModule.register();
        IgrCategoryToolTipLayerModule.register();
        IgrCategoryHighlightLayerModule.register();
        IgrCategoryItemHighlightLayerModule.register();
        IgrFinalValueLayerModule.register();
        IgrDataChartCategoryTrendLineModule.register();
        IgrDataChartAnnotationModule.register();
    };
    return IgrCategoryChartModule;
}());
export { IgrCategoryChartModule };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/igr-category-chart-module.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { IgrCategoryChartCoreModule } from './igr-category-chart-core-module';
import { IgrLineSeriesModule } from './igr-line-series-module';
import { IgrAreaSeriesModule } from './igr-area-series-module';
import { IgrColumnSeriesModule } from './igr-column-series-module';
import { IgrSplineSeriesModule } from './igr-spline-series-module';
import { IgrSplineAreaSeriesModule } from './igr-spline-area-series-module';
import { IgrStepLineSeriesModule } from './igr-step-line-series-module';
import { IgrStepAreaSeriesModule } from './igr-step-area-series-module';
import { IgrPointSeriesModule } from './igr-point-series-module';
import { IgrWaterfallSeriesModule } from './igr-waterfall-series-module';
import { IgrCrosshairLayerModule } from './igr-crosshair-layer-module';
import { IgrCalloutLayerModule } from './igr-callout-layer-module';
import { IgrItemToolTipLayerModule } from './igr-item-tool-tip-layer-module';
import { IgrCategoryToolTipLayerModule } from './igr-category-tool-tip-layer-module';
import { IgrCategoryHighlightLayerModule } from './igr-category-highlight-layer-module';
import { IgrCategoryItemHighlightLayerModule } from './igr-category-item-highlight-layer-module';
import { IgrFinalValueLayerModule } from './igr-final-value-layer-module';
import { IgrNumberAbbreviatorModule } from './igr-number-abbreviator-module';
import { IgrDataChartInteractivityModule } from './igr-data-chart-interactivity-module';
import { IgrDataChartCategoryTrendLineModule } from './igr-data-chart-category-trend-line-module';
import { IgrDataChartAnnotationModule } from './igr-data-chart-annotation-module';
var IgrCategoryChartModule = /** @class */ (function () {
    function IgrCategoryChartModule() {
    }
    IgrCategoryChartModule.register = function () {
        IgrCategoryChartCoreModule.register();
        IgrLineSeriesModule.register();
        IgrAreaSeriesModule.register();
        IgrColumnSeriesModule.register();
        IgrSplineSeriesModule.register();
        IgrSplineAreaSeriesModule.register();
        IgrStepLineSeriesModule.register();
        IgrStepAreaSeriesModule.register();
        IgrPointSeriesModule.register();
        IgrWaterfallSeriesModule.register();
        IgrCrosshairLayerModule.register();
        IgrCalloutLayerModule.register();
        IgrItemToolTipLayerModule.register();
        IgrCategoryToolTipLayerModule.register();
        IgrCategoryHighlightLayerModule.register();
        IgrCategoryItemHighlightLayerModule.register();
        IgrFinalValueLayerModule.register();
        IgrNumberAbbreviatorModule.register();
        IgrDataChartInteractivityModule.register();
        IgrDataChartCategoryTrendLineModule.register();
        IgrDataChartAnnotationModule.register();
    };
    return IgrCategoryChartModule;
}());
export { IgrCategoryChartModule };
